@@ -10,12 +10,10 @@ from django.core.checks import Critical
 from django.core.checks import register
 from django.core.exceptions import ImproperlyConfigured
 from django.db import connections
+from django.db.models.signals import post_migrate
 
-from educommon.audit_log.constants import PG_LOCK_ID
-from educommon.utils.db.postgresql import Lock
 from educommon.utils.db.postgresql import create_extension
 from educommon.utils.db.postgresql import is_extension_exists
-from educommon.utils.system import is_in_migration_command
 
 
 class AppConfig(AppConfig):
@@ -67,22 +65,18 @@ class AppConfig(AppConfig):
                 u"настроен корректно.".format(error_message)
             )
 
-    def ready(self):
-        from .config import config
+    def _configure_db(self, **kwargs):
         from .utils import is_initialized
 
-        with Lock(settings.DEFAULT_DB_ALIAS, PG_LOCK_ID):
-            if is_in_migration_command():
-                self._create_postgresql_extensions()
-                return
+        self._create_postgresql_extensions()
+        if is_initialized(settings.DEFAULT_DB_ALIAS):
+            self._configure_audit_log(
+                connections[settings.DEFAULT_DB_ALIAS]
+            )
+
+    def ready(self):
+        post_migrate.connect(self._configure_db, sender=self)
 
-            if (
-                not config.skip_configure and
-                is_initialized(settings.DEFAULT_DB_ALIAS)
-            ):
-                self._configure_audit_log(
-                    connections[settings.DEFAULT_DB_ALIAS]
-                )
 
 
 @register
