@@ -1,12 +1,12 @@
 DO
 $do$
 BEGIN
-    IF EXISTS(SELECT * FROM pg_proc
-              WHERE proname = 'set_for_selective_tables_triggers') THEN
-        IF pg_try_advisory_lock({lock_id}) THEN
+    IF pg_try_advisory_lock({lock_id}) THEN
+        IF EXISTS(SELECT 1 FROM pg_proc
+                  WHERE proname = 'set_for_selective_tables_triggers') THEN
             PERFORM audit.set_for_selective_tables_triggers();
-            PERFORM pg_advisory_unlock({lock_id});
         END IF;
+        PERFORM pg_advisory_unlock({lock_id});
     END IF;
 EXCEPTION
     WHEN OTHERS THEN
